@@ -25,7 +25,8 @@ class SendGrid(object):
             "lists": {  # recipient lists
                 "add": "/api/newsletter/lists/add.json",
                 "edit": "/api/newsletter/lists/edit.json",
-                "get": "/api/newsletter/lists/get.json"},
+                "get": "/api/newsletter/lists/get.json",
+                "del": "/api/newsletter/lists/delete.json"},
             "email": {  # emails of recipient list
                 "add": "/api/newsletter/lists/email/add.json",
                 "edit": "/api/newsletter/lists/email/edit.json",
@@ -43,21 +44,22 @@ class SendGrid(object):
                 "add": "/api/newsletter/identity/add.json",
                 "list": "/api/newsletter/identity/list.json",
                 "get": "/api/newsletter/identity/get.json"},
-            "subuser":{ #create new subuser
+            "subuser": {  # create new subuser
                 "add": "/apiv2/customer.add.json",
-                "list": "/apiv2/customer.profile.json"},
-            "sendip":{ #create new subuser
+                "list": "/apiv2/customer.profile.json",
+                "del": "/apiv2/customer.delete.json"},
+            "sendip": {  # create new subuser
                 "add": "/apiv2/customer.sendip.json",
                 "get": "/apiv2/customer.ip.json"},
-            "apps":{
+            "apps": {
                 "activate": "/apiv2/customer.apps.json",
                 "customize": "/apiv2/customer.apps.json"},
-            "category":{
+            "category": {
                 "create": "/api/newsletter/category/create.json",
                 "del": "/api/newsletter/category/remove.json",
                 "list": "/api/newsletter/category/list.json",
                 "add": "/api/newsletter/category/add.json"},
-            "stats":{
+            "stats": {
                 "get": "/apiv2/customer.stats.json"}
         }
 
@@ -144,6 +146,9 @@ class SendGrid(object):
     def get_list(self, name=None):
         return self.call('lists', 'get', {"list": name} if name else {})
 
+    def del_list(self, name):
+        return self.call('lists', 'del', dict(list=name))
+
     def add_email_to(self, **fields):
         return self.call('email', 'add', dict(**fields))
 
@@ -204,6 +209,9 @@ class SendGrid(object):
     def list_subusers(self):
         return self.call('subuser', 'list', dict(task="get"))
 
+    def del_subuser(self, user):
+        return self.call('subuser', 'del', dict(user=user))
+
     def add_sendip(self, **fields):
         '''Fields can be task, user, set, ip'''
         return self.call('sendip', 'add', dict(task="append", **fields))
